///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
//
// Filename: JTC_NTSC_240_192_v001.h
//
// Original Author: JT Cook
//
// Last Modified: 1.12.09
//
// Description: Header file for my graphics driver. 240x194
//
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// INCLUDES
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

// watch for multiple inclusions
#ifndef JTC_NTSC_240_192_v001
#define JTC_NTSC_240_192_v001

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// MACROS
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

// simply interogate the video driver's g_CurrentLine variable and determine where the scanline is
#define VIDEO_ACTIVE(video_line)          ( ((video_line) >= START_ACTIVE_SCAN && (video_line) < END_ACTIVE_SCAN))
#define VIDEO_INACTIVE(video_line)        ( ((video_line) < START_ACTIVE_SCAN || (video_line) >= END_ACTIVE_SCAN))
#define VIDEO_TOP_OVERSCAN(video_line)    ( ((video_line) >= 0 && (video_line) < START_ACTIVE_SCAN))
#define VIDEO_BOT_OVERSCAN(video_line)    ( ((video_line) >= END_ACTIVE_SCAN))

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// DEFINES
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
#define SCREEN_TILE_MAP_WIDTH	30
#define SCREEN_TILE_MAP_HEIGHT	24
#define TILE_WIDTH				8
#define TILE_HEIGHT				8

#define SCREEN_WIDTH		240
#define SCREEN_HEIGHT		192
#define SCREEN_BPP			8

// Used for allocating buffers in main program
#define MAX_PALETTE_SIZE		256

#define VERTICAL_OFFSET		40
#define LINE_REPT_COUNT		1

#define START_VIDEO_SCAN    0
#define START_ACTIVE_SCAN   (VERTICAL_OFFSET)
#define END_ACTIVE_SCAN     (SCREEN_HEIGHT*LINE_REPT_COUNT + VERTICAL_OFFSET)
#define END_VIDEO_SCAN      261

#define MAX_SPRITES				8

// Sprite state controls
#define SPRITE_STATE_ON			0x01
#define SPRITE_STATE_OFF		0x00
#define SPRITE_STATE_ON_MASK	0x01


////
#define SCREEN_WIDTH		240
#define SCREEN_HEIGHT		192
#define SCREEN_BPP			8

#define VERTICAL_OFFSET		40
#define LINE_REPT_COUNT		2

#define START_VIDEO_SCAN    0
#define START_ACTIVE_SCAN   (VERTICAL_OFFSET)
#define END_ACTIVE_SCAN     (SCREEN_HEIGHT*LINE_REPT_COUNT + VERTICAL_OFFSET)
#define END_VIDEO_SCAN      261


#define NUM_PIXELS_PER_BYTE	1

// Used for allocating buffers in main program
#define VRAM_BUF_SIZE			(SCREEN_WIDTH/NUM_PIXELS_PER_BYTE)*SCREEN_HEIGHT
#define PALETTE_MAP_SIZE		(SCREEN_WIDTH/8)*(SCREEN_HEIGHT/8)
#define MIN_PALETTE_SIZE		16

// Common NTSC colors
#define COLOR_LUMA		(0x91)

#define NTSC_GREEN  	(COLOR_LUMA + 0)
#define NTSC_YELLOW   	(COLOR_LUMA + 2)
#define NTSC_ORANGE   	(COLOR_LUMA + 4)
#define NTSC_RED      	(COLOR_LUMA + 5)
#define NTSC_VIOLET   	(COLOR_LUMA + 9)
#define NTSC_PURPLE   	(COLOR_LUMA + 11)
#define NTSC_BLUE     	(COLOR_LUMA + 13)

#define NTSC_BLACK   	(0x4F)

#define NTSC_GRAY0    	(NTSC_BLACK + 0x10)
#define NTSC_GRAY1    	(NTSC_BLACK + 0x20)
#define NTSC_GRAY2    	(NTSC_BLACK + 0x30)
#define NTSC_GRAY3    	(NTSC_BLACK + 0x40)
#define NTSC_GRAY4    	(NTSC_BLACK + 0x50)
#define NTSC_GRAY5    	(NTSC_BLACK + 0x60)
#define NTSC_GRAY6    	(NTSC_BLACK + 0x70)
#define NTSC_GRAY7    	(NTSC_BLACK + 0x80)
#define NTSC_GRAY8    	(NTSC_BLACK + 0x90)
#define NTSC_GRAY9    	(NTSC_BLACK + 0xA0)
#define NTSC_WHITE    	(NTSC_BLACK + 0xB0)


///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// GLOBALS
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// EXTERNALS
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// PROTOTYPES
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////


// end multiple inclusions
#endif
