///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
//         
// Filename: JTC_NTSC_GFX_DRV_v002.h
//
// Author: JT Cook - http://www.avalondreams.com
// 
// Support file for 30x24 and 8 16x16 sprites
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// INCLUDES
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// watch for multiple inclusions
#ifndef JTC_NTSC_GFX_DVR_v002
#define JTC_NTSC_GFX_DVR_v002

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// MACROS
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// DEFINES
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

// Wait for Vsync macros
#define WAIT_FOR_VSYNC_START()  while(!g_VsyncFlag);
#define WAIT_FOR_VSYNC_END()	while(g_VsyncFlag);

#define MAX_SPRITES 8 //define max number of sprites
//define tile X,Y size
#define SCREEN_TILE_MAP_WIDTH 30
#define SCREEN_TILE_MAP_HEIGHT 24

// Types used for GFX_StartDrawing function (used primarily to setup the timer interrupt period
#define SCREEN_TYPE_NTSC		0
#define SCREEN_TYPE_VGA			1

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// STRUCTS
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

// The following is the sprite structure
typedef struct{
	unsigned char State;			// State of the Sprite (SPRITE_STATE_ON/OFF)
	unsigned char Attribute;		// Attribute of the sprite (NOT USED)
	unsigned int X;					// X position of the sprite
	unsigned int Y;					// Y position of the sprite
	unsigned char *PixelData;		// Pointer to the bitmap data of the sprite
} Sprite, *SpritePtr;



///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// EXTERNALS
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

volatile extern unsigned int g_CurrentLine;   	// Current physical line 0...524(VGA),261(NTSC)
volatile extern int g_RasterLine;           	// Current logical raster line
volatile extern int g_VsyncFlag;				// Flag to indicate whether we are in v-sync or not

extern unsigned char *g_TileMapBasePtr;			// Used to do coarse scrolling in a tile map engine
extern unsigned char *g_TileSet; 				// 16-bit pointer to a Character set as 8(6)x8 with 1 byte per pixel
extern Sprite *g_SpriteList;					// 16-bit pointer to sprite table records

extern int g_TileMapWidth;						// Used to store the tile map width for text console modes
extern int g_TileMapHeight;						// Used to store the tile map height for text console modes
extern int g_Tmap_Cursor_X;						// Text mode cursor x position
extern int g_Tmap_Cursor_Y;						// Text mode cursor y position

// Initializes the graphics engine
void GFX_InitTile(unsigned char *TileData, unsigned char *TileMap, Sprite *SpriteTable);

// Starts the timer1 interrupt which calls our assembly video driver code
void GFX_StartDrawing(int ScreenType);

//fills the screen with a select character
void fill_screen(char digit);

//places a tile
void draw_tile(int x, int y, char tile_pic);

// end multiple inclusions
#endif
